Crate dictcc

Rust API for reading and querying the dict.cc offline translation database.

Modules

  • Error handling.
  • Grouped representation and pretty printing of DictQueryResult in tabular form.
  • Parsing and AST of the bracket syntax of dict.cc, see Guidelines

Structs

  • Structure that contains all dictionary entries
  • Structure that holds the word pair and it’s class
  • A pair of two languages. Identifies the languages of a single translation database file.
  • Builder for a DictQueryResult.
  • Result of a translation query
  • Structure that contains all fields of a dictionary entry from dict.cc

Enums

  • Lists all available genders
  • Lists all available languages
  • In which direction a query is executed. Used by DictQuery. Can be inferred by DictLanguagePair::infer_query_direction.
  • Different types of queries. Used by DictQuery.
  • Lists all available WordClasses